<?php
$lan = array(
  'sent' => 'enviada',
  'draft' => 'rascunho',
  'queued' => 'listada',
  'static' => 'est&aacute;tica',
  'Deleting' => 'Apagando',
  'Done' => 'Conclu&iacute;da',
  'failed' => 'falhou',
  'Suspending' => 'Suspendendo',
  'Requeuing' => 'Redistribuir',
  'Listing message' => 'Listando mensagem',
  'to' => 'a', //in sentence: 'listing message 1 TO 50'
  'Listing message 1 to' => 'Listando mensagem de 1 a',
  'Messages' => 'Mensagens',
  'Delete all draft messages without subject' => 'Apagar todas as mensagens com assunto em branco',
  'Delete all draft messages' => 'Apagar todas as mensagens de rascunho',
  'Message info' => 'Informa&ccedil;&otilde;es sobre a mensagem',
  'Status' => 'Status',
  'Action' => 'A&ccedil;&atilde;o',
  'From:' => 'De:',
  'Subject:' => 'Assunto:',
  'Entered:' => 'Inserida:',
  'Embargo:' => 'Bloqueada:',
  'delete' => 'apagar',
  'click stats' => 'Estat&iacute;sticas de cliques',
  'Sent' => 'Enviada',
  'Time to send' => 'Hora para ser enviada',
  'total' => 'total',
  'text' => 'texto',
  'html' => 'html',
  'both' => 'ambos',
  'PDF' => 'PDF',
  'Viewed' => 'Exibida',
  'Unique Views' => 'Exibidas uma vez',
  'Clicks' => 'Cliques',
  'Bounced' => 'Com Problemas',
  'still to process' => 'a processar',
  'ETA' => 'ETA',
  'Processing' => 'Processando',
  'msgs/hr' => 'msgs/hr',
  'Suspend Sending' => 'Parar Envio',
  'View' => 'Exibir',
  'inprocess' => 'em processo',
  'Requeue' => 'Redistribuir',
  'processed' => 'processada',
  'prepared' => 'pronta',
  'Edit' => 'Editar',
);
?>
